==> ggeffects_1.2.3.tar.gz: ggeffects/tests/testthat/_snaps/print_hypothesis_test-ordinal.md <==
# print hypothesis_test ordinal outcome

    Code
      print(out)
    Output
      # Pairwise comparisons
      
      Response Level by Type          |  Contrast
      -------------------------------------------
      Low-Tower-Low-Apartment         |     -0.14
      Low-Tower-Low-Atrium            |     -0.09
      Low-Tower-Low-Terrace           |     -0.27
      Low-Tower-Medium-Tower          |      0.09
      Low-Tower-Medium-Apartment      |      0.12
      Low-Tower-Medium-Atrium         |      0.10
      Low-Tower-Medium-Terrace        |      0.17
      Low-Tower-High-Tower            |      0.04
      Low-Tower-High-Apartment        |      0.16
      Low-Tower-High-Atrium           |      0.12
      Low-Tower-High-Terrace          |      0.23
      Low-Apartment-Low-Atrium        |      0.05
      Low-Apartment-Low-Terrace       |     -0.13
      Low-Apartment-Medium-Tower      |      0.23
      Low-Apartment-Medium-Apartment  |      0.26
      Low-Apartment-Medium-Atrium     |      0.24
      Low-Apartment-Medium-Terrace    |      0.31
      Low-Apartment-High-Tower        |      0.18
      Low-Apartment-High-Apartment    |      0.30
      Low-Apartment-High-Atrium       |      0.26
      Low-Apartment-High-Terrace      |      0.37
      Low-Atrium-Low-Terrace          |     -0.18
      Low-Atrium-Medium-Tower         |      0.18
      Low-Atrium-Medium-Apartment     |      0.21
      Low-Atrium-Medium-Atrium        |      0.19
      Low-Atrium-Medium-Terrace       |      0.26
      Low-Atrium-High-Tower           |      0.13
      Low-Atrium-High-Apartment       |      0.25
      Low-Atrium-High-Atrium          |      0.21
      Low-Atrium-High-Terrace         |      0.32
      Low-Terrace-Medium-Tower        |      0.36
      Low-Terrace-Medium-Apartment    |      0.38
      Low-Terrace-Medium-Atrium       |      0.37
      Low-Terrace-Medium-Terrace      |      0.43
      Low-Terrace-High-Tower          |      0.31
      Low-Terrace-High-Apartment      |      0.42
      Low-Terrace-High-Atrium         |      0.39
      Low-Terrace-High-Terrace        |      0.50
      Medium-Tower-Medium-Apartment   |      0.03
      Medium-Tower-Medium-Atrium      |      0.01
      Medium-Tower-Medium-Terrace     |      0.08
      Medium-Tower-High-Tower         |     -0.05
      Medium-Tower-High-Apartment     |      0.07
      Medium-Tower-High-Atrium        |      0.03
      Medium-Tower-High-Terrace       |      0.14
      Medium-Apartment-Medium-Atrium  |     -0.01
      Medium-Apartment-Medium-Terrace |      0.05
      Medium-Apartment-High-Tower     |     -0.07
      Medium-Apartment-High-Apartment |      0.04
      Medium-Apartment-High-Atrium    |  2.38e-03
      Medium-Apartment-High-Terrace   |      0.12
      Medium-Atrium-Medium-Terrace    |      0.06
      Medium-Atrium-High-Tower        |     -0.06
      Medium-Atrium-High-Apartment    |      0.05
      Medium-Atrium-High-Atrium       |      0.02
      Medium-Atrium-High-Terrace      |      0.13
      Medium-Terrace-High-Tower       |     -0.12
      Medium-Terrace-High-Apartment   | -8.97e-03
      Medium-Terrace-High-Atrium      |     -0.05
      Medium-Terrace-High-Terrace     |      0.07
      High-Tower-High-Apartment       |      0.11
      High-Tower-High-Atrium          |      0.08
      High-Tower-High-Terrace         |      0.19
      High-Apartment-High-Atrium      |     -0.04
      High-Apartment-High-Terrace     |      0.08
      High-Atrium-High-Terrace        |      0.11
    Message <simpleMessage>
      
      Contrasts are presented as probabilities.

---

    Code
      print(out)
    Output
      # Pairwise comparisons
      
      Response Level by Type & x            |  Contrast
      -------------------------------------------------
      Low-Terrace-1-Low-Apartment-1         |      0.13
      Low-Terrace-1-Low-Terrace-2           |  2.85e-03
      Low-Terrace-1-Low-Apartment-2         |      0.13
      Low-Terrace-1-Medium-Terrace-1        |      0.43
      Low-Terrace-1-Medium-Apartment-1      |      0.38
      Low-Terrace-1-Medium-Terrace-2        |      0.43
      Low-Terrace-1-Medium-Apartment-2      |      0.38
      Low-Terrace-1-High-Terrace-1          |      0.49
      Low-Terrace-1-High-Apartment-1        |      0.42
      Low-Terrace-1-High-Terrace-2          |      0.49
      Low-Terrace-1-High-Apartment-2        |      0.42
      Low-Apartment-1-Low-Terrace-2         |     -0.12
      Low-Apartment-1-Low-Apartment-2       |  3.08e-03
      Low-Apartment-1-Medium-Terrace-1      |      0.30
      Low-Apartment-1-Medium-Apartment-1    |      0.25
      Low-Apartment-1-Medium-Terrace-2      |      0.30
      Low-Apartment-1-Medium-Apartment-2    |      0.25
      Low-Apartment-1-High-Terrace-1        |      0.37
      Low-Apartment-1-High-Apartment-1      |      0.29
      Low-Apartment-1-High-Terrace-2        |      0.37
      Low-Apartment-1-High-Apartment-2      |      0.29
      Low-Terrace-2-Low-Apartment-2         |      0.13
      Low-Terrace-2-Medium-Terrace-1        |      0.42
      Low-Terrace-2-Medium-Apartment-1      |      0.38
      Low-Terrace-2-Medium-Terrace-2        |      0.42
      Low-Terrace-2-Medium-Apartment-2      |      0.38
      Low-Terrace-2-High-Terrace-1          |      0.49
      Low-Terrace-2-High-Apartment-1        |      0.41
      Low-Terrace-2-High-Terrace-2          |      0.49
      Low-Terrace-2-High-Apartment-2        |      0.41
      Low-Apartment-2-Medium-Terrace-1      |      0.30
      Low-Apartment-2-Medium-Apartment-1    |      0.25
      Low-Apartment-2-Medium-Terrace-2      |      0.30
      Low-Apartment-2-Medium-Apartment-2    |      0.25
      Low-Apartment-2-High-Terrace-1        |      0.37
      Low-Apartment-2-High-Apartment-1      |      0.29
      Low-Apartment-2-High-Terrace-2        |      0.36
      Low-Apartment-2-High-Apartment-2      |      0.29
      Medium-Terrace-1-Medium-Apartment-1   |     -0.05
      Medium-Terrace-1-Medium-Terrace-2     | -1.30e-03
      Medium-Terrace-1-Medium-Apartment-2   |     -0.05
      Medium-Terrace-1-High-Terrace-1       |      0.07
      Medium-Terrace-1-High-Apartment-1     | -9.82e-03
      Medium-Terrace-1-High-Terrace-2       |      0.07
      Medium-Terrace-1-High-Apartment-2     |     -0.01
      Medium-Apartment-1-Medium-Terrace-2   |      0.05
      Medium-Apartment-1-Medium-Apartment-2 | -9.37e-04
      Medium-Apartment-1-High-Terrace-1     |      0.12
      Medium-Apartment-1-High-Apartment-1   |      0.04
      Medium-Apartment-1-High-Terrace-2     |      0.11
      Medium-Apartment-1-High-Apartment-2   |      0.04
      Medium-Terrace-2-Medium-Apartment-2   |     -0.05
      Medium-Terrace-2-High-Terrace-1       |      0.07
      Medium-Terrace-2-High-Apartment-1     | -8.52e-03
      Medium-Terrace-2-High-Terrace-2       |      0.07
      Medium-Terrace-2-High-Apartment-2     |     -0.01
      Medium-Apartment-2-High-Terrace-1     |      0.12
      Medium-Apartment-2-High-Apartment-1   |      0.04
      Medium-Apartment-2-High-Terrace-2     |      0.11
      Medium-Apartment-2-High-Apartment-2   |      0.04
      High-Terrace-1-High-Apartment-1       |     -0.08
      High-Terrace-1-High-Terrace-2         | -1.55e-03
      High-Terrace-1-High-Apartment-2       |     -0.08
      High-Apartment-1-High-Terrace-2       |      0.08
      High-Apartment-1-High-Apartment-2     | -2.15e-03
      High-Terrace-2-High-Apartment-2       |     -0.08
    Message <simpleMessage>
      
      Contrasts are presented as probabilities.

---

    Code
      print(out)
    Output
      
      # Response Level: Low
      
      Type      | Predicted
      ---------------------
      Tower     |      0.38
      Apartment |      0.52
      Atrium    |      0.47
      Terrace   |      0.64
      
      # Response Level: Medium
      
      Type      | Predicted
      ---------------------
      Tower     |      0.29
      Apartment |      0.26
      Atrium    |      0.27
      Terrace   |      0.21
      
      # Response Level: High
      
      Type      | Predicted
      ---------------------
      Tower     |      0.33
      Apartment |      0.22
      Atrium    |      0.26
      Terrace   |      0.14
    Message <simpleMessage>
      
      Predictions are presented as probabilities.

---

    Code
      print(out)
    Output
      
      # Response Level: Low
      
      Type      |    x | Predicted
      ----------------------------
      Terrace   | 1.00 |      0.64
      Apartment | 1.00 |      0.52
      Terrace   | 2.00 |      0.64
      Apartment | 2.00 |      0.51
      
      # Response Level: Medium
      
      Type      |    x | Predicted
      ----------------------------
      Terrace   | 1.00 |      0.21
      Apartment | 1.00 |      0.26
      Terrace   | 2.00 |      0.21
      Apartment | 2.00 |      0.26
      
      # Response Level: High
      
      Type      |    x | Predicted
      ----------------------------
      Terrace   | 1.00 |      0.15
      Apartment | 1.00 |      0.22
      Terrace   | 2.00 |      0.15
      Apartment | 2.00 |      0.23
    Message <simpleMessage>
      
      Predictions are presented as probabilities.

# print hypothesis_test categorical outcome

    Code
      print(out)
    Output
      # Pairwise comparisons
      
      Response Level by gender                  |  Contrast |         95% CI |      p
      -------------------------------------------------------------------------------
      definitely-male-definitely-female         |      0.02 | [-0.02,  0.06] | 0.371 
      definitely-male-probably-male             |     -0.14 | [-0.27,  0.00] | 0.042 
      definitely-male-probably-female           |     -0.17 | [-0.28, -0.06] | 0.002 
      definitely-male-probably not-male         |      0.14 | [ 0.03,  0.25] | 0.013 
      definitely-male-probably not-female       |      0.16 | [ 0.07,  0.25] | < .001
      definitely-male-definitely not-male       |      0.20 | [ 0.17,  0.23] | < .001
      definitely-male-definitely not-female     |      0.19 | [ 0.15,  0.23] | < .001
      definitely-female-probably-male           |     -0.15 | [-0.27, -0.04] | 0.010 
      definitely-female-probably-female         |     -0.19 | [-0.30, -0.07] | 0.002 
      definitely-female-probably not-male       |      0.12 | [ 0.01,  0.23] | 0.029 
      definitely-female-probably not-female     |      0.14 | [ 0.05,  0.22] | 0.001 
      definitely-female-definitely not-male     |      0.18 | [ 0.15,  0.21] | < .001
      definitely-female-definitely not-female   |      0.17 | [ 0.15,  0.19] | < .001
      probably-male-probably-female             |     -0.03 | [-0.18,  0.12] | 0.678 
      probably-male-probably not-male           |      0.27 | [ 0.06,  0.49] | 0.012 
      probably-male-probably not-female         |      0.29 | [ 0.15,  0.43] | < .001
      probably-male-definitely not-male         |      0.33 | [ 0.21,  0.45] | < .001
      probably-male-definitely not-female       |      0.33 | [ 0.21,  0.44] | < .001
      probably-female-probably not-male         |      0.31 | [ 0.16,  0.45] | < .001
      probably-female-probably not-female       |      0.32 | [ 0.14,  0.51] | < .001
      probably-female-definitely not-male       |      0.36 | [ 0.26,  0.47] | < .001
      probably-female-definitely not-female     |      0.36 | [ 0.25,  0.47] | < .001
      probably not-male-probably not-female     |      0.02 | [-0.11,  0.15] | 0.793 
      probably not-male-definitely not-male     |      0.06 | [-0.05,  0.17] | 0.280 
      probably not-male-definitely not-female   |      0.05 | [-0.05,  0.16] | 0.316 
      probably not-female-definitely not-male   |      0.04 | [-0.05,  0.13] | 0.354 
      probably not-female-definitely not-female |      0.04 | [-0.04,  0.12] | 0.378 
      definitely not-male-definitely not-female | -4.73e-03 | [-0.03,  0.02] | 0.726 
    Message <simpleMessage>
      
      Contrasts are presented as probabilities.

---

    Code
      print(out)
    Output
      
      # Response Level: definitely
      
      gender | Predicted |       95% CI |      p
      ------------------------------------------
      male   |      0.30 | [0.27, 0.33] | < .001
      female |      0.28 | [0.26, 0.31] | < .001
      
      # Response Level: probably
      
      gender | Predicted |       95% CI |      p
      ------------------------------------------
      male   |      0.44 | [0.32, 0.55] | < .001
      female |      0.47 | [0.37, 0.57] | < .001
      
      # Response Level: probably not
      
      gender | Predicted |       95% CI |      p
      ------------------------------------------
      male   |      0.16 | [0.06, 0.27] | 0.002 
      female |      0.14 | [0.06, 0.23] | < .001
      
      # Response Level: definitely not
      
      gender | Predicted |       95% CI |      p
      ------------------------------------------
      male   |      0.10 | [0.08, 0.12] | < .001
      female |      0.11 | [0.09, 0.13] | < .001
    Message <simpleMessage>
      
      Predictions are presented as probabilities.

==> ggeffects_1.3.1.tar.gz: ggeffects/tests/testthat/_snaps/print_hypothesis_test-ordinal.md <==
# print hypothesis_test ordinal outcome

    Code
      print(out)
    Output
      # Pairwise comparisons
      
      Response Level by Type          |  Contrast
      -------------------------------------------
      Low-Tower-Low-Apartment         |     -0.14
      Low-Tower-Low-Atrium            |     -0.09
      Low-Tower-Low-Terrace           |     -0.27
      Low-Tower-Medium-Tower          |      0.09
      Low-Tower-Medium-Apartment      |      0.12
      Low-Tower-Medium-Atrium         |      0.10
      Low-Tower-Medium-Terrace        |      0.17
      Low-Tower-High-Tower            |      0.04
      Low-Tower-High-Apartment        |      0.16
      Low-Tower-High-Atrium           |      0.12
      Low-Tower-High-Terrace          |      0.23
      Low-Apartment-Low-Atrium        |      0.05
      Low-Apartment-Low-Terrace       |     -0.13
      Low-Apartment-Medium-Tower      |      0.23
      Low-Apartment-Medium-Apartment  |      0.26
      Low-Apartment-Medium-Atrium     |      0.24
      Low-Apartment-Medium-Terrace    |      0.31
      Low-Apartment-High-Tower        |      0.18
      Low-Apartment-High-Apartment    |      0.30
      Low-Apartment-High-Atrium       |      0.26
      Low-Apartment-High-Terrace      |      0.37
      Low-Atrium-Low-Terrace          |     -0.18
      Low-Atrium-Medium-Tower         |      0.18
      Low-Atrium-Medium-Apartment     |      0.21
      Low-Atrium-Medium-Atrium        |      0.19
      Low-Atrium-Medium-Terrace       |      0.26
      Low-Atrium-High-Tower           |      0.13
      Low-Atrium-High-Apartment       |      0.25
      Low-Atrium-High-Atrium          |      0.21
      Low-Atrium-High-Terrace         |      0.32
      Low-Terrace-Medium-Tower        |      0.36
      Low-Terrace-Medium-Apartment    |      0.38
      Low-Terrace-Medium-Atrium       |      0.37
      Low-Terrace-Medium-Terrace      |      0.43
      Low-Terrace-High-Tower          |      0.31
      Low-Terrace-High-Apartment      |      0.42
      Low-Terrace-High-Atrium         |      0.39
      Low-Terrace-High-Terrace        |      0.50
      Medium-Tower-Medium-Apartment   |      0.03
      Medium-Tower-Medium-Atrium      |      0.01
      Medium-Tower-Medium-Terrace     |      0.08
      Medium-Tower-High-Tower         |     -0.05
      Medium-Tower-High-Apartment     |      0.07
      Medium-Tower-High-Atrium        |      0.03
      Medium-Tower-High-Terrace       |      0.14
      Medium-Apartment-Medium-Atrium  |     -0.01
      Medium-Apartment-Medium-Terrace |      0.05
      Medium-Apartment-High-Tower     |     -0.07
      Medium-Apartment-High-Apartment |      0.04
      Medium-Apartment-High-Atrium    |  2.38e-03
      Medium-Apartment-High-Terrace   |      0.12
      Medium-Atrium-Medium-Terrace    |      0.06
      Medium-Atrium-High-Tower        |     -0.06
      Medium-Atrium-High-Apartment    |      0.05
      Medium-Atrium-High-Atrium       |      0.02
      Medium-Atrium-High-Terrace      |      0.13
      Medium-Terrace-High-Tower       |     -0.12
      Medium-Terrace-High-Apartment   | -8.97e-03
      Medium-Terrace-High-Atrium      |     -0.05
      Medium-Terrace-High-Terrace     |      0.07
      High-Tower-High-Apartment       |      0.11
      High-Tower-High-Atrium          |      0.08
      High-Tower-High-Terrace         |      0.19
      High-Apartment-High-Atrium      |     -0.04
      High-Apartment-High-Terrace     |      0.08
      High-Atrium-High-Terrace        |      0.11
    Message <simpleMessage>
      
      Contrasts are presented as probabilities.

---

    Code
      print(out)
    Output
      # Pairwise comparisons
      
      Response Level by Type & x            |  Contrast
      -------------------------------------------------
      Low-Terrace-1-Low-Terrace-2           |  2.85e-03
      Low-Terrace-1-Low-Apartment-1         |      0.13
      Low-Terrace-1-Low-Apartment-2         |      0.13
      Low-Terrace-1-Medium-Terrace-1        |      0.43
      Low-Terrace-1-Medium-Terrace-2        |      0.43
      Low-Terrace-1-Medium-Apartment-1      |      0.38
      Low-Terrace-1-Medium-Apartment-2      |      0.38
      Low-Terrace-1-High-Terrace-1          |      0.49
      Low-Terrace-1-High-Terrace-2          |      0.49
      Low-Terrace-1-High-Apartment-1        |      0.42
      Low-Terrace-1-High-Apartment-2        |      0.42
      Low-Terrace-2-Low-Apartment-1         |      0.12
      Low-Terrace-2-Low-Apartment-2         |      0.13
      Low-Terrace-2-Medium-Terrace-1        |      0.42
      Low-Terrace-2-Medium-Terrace-2        |      0.42
      Low-Terrace-2-Medium-Apartment-1      |      0.38
      Low-Terrace-2-Medium-Apartment-2      |      0.38
      Low-Terrace-2-High-Terrace-1          |      0.49
      Low-Terrace-2-High-Terrace-2          |      0.49
      Low-Terrace-2-High-Apartment-1        |      0.41
      Low-Terrace-2-High-Apartment-2        |      0.41
      Low-Apartment-1-Low-Apartment-2       |  3.08e-03
      Low-Apartment-1-Medium-Terrace-1      |      0.30
      Low-Apartment-1-Medium-Terrace-2      |      0.30
      Low-Apartment-1-Medium-Apartment-1    |      0.25
      Low-Apartment-1-Medium-Apartment-2    |      0.25
      Low-Apartment-1-High-Terrace-1        |      0.37
      Low-Apartment-1-High-Terrace-2        |      0.37
      Low-Apartment-1-High-Apartment-1      |      0.29
      Low-Apartment-1-High-Apartment-2      |      0.29
      Low-Apartment-2-Medium-Terrace-1      |      0.30
      Low-Apartment-2-Medium-Terrace-2      |      0.30
      Low-Apartment-2-Medium-Apartment-1    |      0.25
      Low-Apartment-2-Medium-Apartment-2    |      0.25
      Low-Apartment-2-High-Terrace-1        |      0.37
      Low-Apartment-2-High-Terrace-2        |      0.36
      Low-Apartment-2-High-Apartment-1      |      0.29
      Low-Apartment-2-High-Apartment-2      |      0.29
      Medium-Terrace-1-Medium-Terrace-2     | -1.30e-03
      Medium-Terrace-1-Medium-Apartment-1   |     -0.05
      Medium-Terrace-1-Medium-Apartment-2   |     -0.05
      Medium-Terrace-1-High-Terrace-1       |      0.07
      Medium-Terrace-1-High-Terrace-2       |      0.07
      Medium-Terrace-1-High-Apartment-1     | -9.82e-03
      Medium-Terrace-1-High-Apartment-2     |     -0.01
      Medium-Terrace-2-Medium-Apartment-1   |     -0.05
      Medium-Terrace-2-Medium-Apartment-2   |     -0.05
      Medium-Terrace-2-High-Terrace-1       |      0.07
      Medium-Terrace-2-High-Terrace-2       |      0.07
      Medium-Terrace-2-High-Apartment-1     | -8.52e-03
      Medium-Terrace-2-High-Apartment-2     |     -0.01
      Medium-Apartment-1-Medium-Apartment-2 | -9.37e-04
      Medium-Apartment-1-High-Terrace-1     |      0.12
      Medium-Apartment-1-High-Terrace-2     |      0.11
      Medium-Apartment-1-High-Apartment-1   |      0.04
      Medium-Apartment-1-High-Apartment-2   |      0.04
      Medium-Apartment-2-High-Terrace-1     |      0.12
      Medium-Apartment-2-High-Terrace-2     |      0.11
      Medium-Apartment-2-High-Apartment-1   |      0.04
      Medium-Apartment-2-High-Apartment-2   |      0.04
      High-Terrace-1-High-Terrace-2         | -1.55e-03
      High-Terrace-1-High-Apartment-1       |     -0.08
      High-Terrace-1-High-Apartment-2       |     -0.08
      High-Terrace-2-High-Apartment-1       |     -0.08
      High-Terrace-2-High-Apartment-2       |     -0.08
      High-Apartment-1-High-Apartment-2     | -2.15e-03
    Message <simpleMessage>
      
      Contrasts are presented as probabilities.

---

    Code
      print(out)
    Output
      
      # Response Level: Low
      
      Type      | Predicted
      ---------------------
      Tower     |      0.38
      Apartment |      0.52
      Atrium    |      0.47
      Terrace   |      0.64
      
      # Response Level: Medium
      
      Type      | Predicted
      ---------------------
      Tower     |      0.29
      Apartment |      0.26
      Atrium    |      0.27
      Terrace   |      0.21
      
      # Response Level: High
      
      Type      | Predicted
      ---------------------
      Tower     |      0.33
      Apartment |      0.22
      Atrium    |      0.26
      Terrace   |      0.14
    Message <simpleMessage>
      
      Predictions are presented as probabilities.

---

    Code
      print(out)
    Output
      
      # Response Level: Low
      
      Type      |    x | Predicted
      ----------------------------
      Terrace   | 1.00 |      0.64
      Terrace   | 2.00 |      0.64
      Apartment | 1.00 |      0.52
      Apartment | 2.00 |      0.51
      
      # Response Level: Medium
      
      Type      |    x | Predicted
      ----------------------------
      Terrace   | 1.00 |      0.21
      Terrace   | 2.00 |      0.21
      Apartment | 1.00 |      0.26
      Apartment | 2.00 |      0.26
      
      # Response Level: High
      
      Type      |    x | Predicted
      ----------------------------
      Terrace   | 1.00 |      0.15
      Terrace   | 2.00 |      0.15
      Apartment | 1.00 |      0.22
      Apartment | 2.00 |      0.23
    Message <simpleMessage>
      
      Predictions are presented as probabilities.

# print hypothesis_test categorical outcome

    Code
      print(out)
    Output
      # Pairwise comparisons
      
      Response Level by gender                  |  Contrast |         95% CI |      p
      -------------------------------------------------------------------------------
      definitely-male-definitely-female         |      0.02 | [-0.02,  0.06] | 0.371 
      definitely-male-probably-male             |     -0.14 | [-0.27,  0.00] | 0.042 
      definitely-male-probably-female           |     -0.17 | [-0.28, -0.06] | 0.002 
      definitely-male-probably not-male         |      0.14 | [ 0.03,  0.25] | 0.013 
      definitely-male-probably not-female       |      0.16 | [ 0.07,  0.25] | < .001
      definitely-male-definitely not-male       |      0.20 | [ 0.17,  0.23] | < .001
      definitely-male-definitely not-female     |      0.19 | [ 0.15,  0.23] | < .001
      definitely-female-probably-male           |     -0.15 | [-0.27, -0.04] | 0.010 
      definitely-female-probably-female         |     -0.19 | [-0.30, -0.07] | 0.002 
      definitely-female-probably not-male       |      0.12 | [ 0.01,  0.23] | 0.029 
      definitely-female-probably not-female     |      0.14 | [ 0.05,  0.22] | 0.001 
      definitely-female-definitely not-male     |      0.18 | [ 0.15,  0.21] | < .001
      definitely-female-definitely not-female   |      0.17 | [ 0.15,  0.19] | < .001
      probably-male-probably-female             |     -0.03 | [-0.18,  0.12] | 0.678 
      probably-male-probably not-male           |      0.27 | [ 0.06,  0.49] | 0.012 
      probably-male-probably not-female         |      0.29 | [ 0.15,  0.43] | < .001
      probably-male-definitely not-male         |      0.33 | [ 0.21,  0.45] | < .001
      probably-male-definitely not-female       |      0.33 | [ 0.21,  0.44] | < .001
      probably-female-probably not-male         |      0.31 | [ 0.16,  0.45] | < .001
      probably-female-probably not-female       |      0.32 | [ 0.14,  0.51] | < .001
      probably-female-definitely not-male       |      0.36 | [ 0.26,  0.47] | < .001
      probably-female-definitely not-female     |      0.36 | [ 0.25,  0.47] | < .001
      probably not-male-probably not-female     |      0.02 | [-0.11,  0.15] | 0.793 
      probably not-male-definitely not-male     |      0.06 | [-0.05,  0.17] | 0.280 
      probably not-male-definitely not-female   |      0.05 | [-0.05,  0.16] | 0.316 
      probably not-female-definitely not-male   |      0.04 | [-0.05,  0.13] | 0.354 
      probably not-female-definitely not-female |      0.04 | [-0.04,  0.12] | 0.378 
      definitely not-male-definitely not-female | -4.73e-03 | [-0.03,  0.02] | 0.726 
    Message <simpleMessage>
      
      Contrasts are presented as probabilities.

---

    Code
      print(out)
    Output
      
      # Response Level: definitely
      
      gender | Predicted |       95% CI |      p
      ------------------------------------------
      male   |      0.30 | [0.27, 0.33] | < .001
      female |      0.28 | [0.26, 0.31] | < .001
      
      # Response Level: probably
      
      gender | Predicted |       95% CI |      p
      ------------------------------------------
      male   |      0.44 | [0.32, 0.55] | < .001
      female |      0.47 | [0.37, 0.57] | < .001
      
      # Response Level: probably not
      
      gender | Predicted |       95% CI |      p
      ------------------------------------------
      male   |      0.16 | [0.06, 0.27] | 0.002 
      female |      0.14 | [0.06, 0.23] | < .001
      
      # Response Level: definitely not
      
      gender | Predicted |       95% CI |      p
      ------------------------------------------
      male   |      0.10 | [0.08, 0.12] | < .001
      female |      0.11 | [0.09, 0.13] | < .001
    Message <simpleMessage>
      
      Predictions are presented as probabilities.
